<?php

namespace Superrobota\Mailing\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Mailing\Models\Mailing;

class MailingPolicy
{

    /**
     * Determine if the given user can view the mailing.
     *
     * @param UserPolicy $user
     * @param Mailing $mailing
     *
     * @return bool
     */
    public function view(UserPolicy $user, Mailing $mailing)
    {
        if ($user->canDo('mailing.mailing.view') && $user->isAdmin()) {
            return true;
        }

        return $mailing->user_id == user_id() && $mailing->user_type == user_type();
    }

    /**
     * Determine if the given user can create a mailing.
     *
     * @param UserPolicy $user
     * @param Mailing $mailing
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('mailing.mailing.create');
    }

    /**
     * Determine if the given user can update the given mailing.
     *
     * @param UserPolicy $user
     * @param Mailing $mailing
     *
     * @return bool
     */
    public function update(UserPolicy $user, Mailing $mailing)
    {
        if ($user->canDo('mailing.mailing.edit') && $user->isAdmin()) {
            return true;
        }

        return $mailing->user_id == user_id() && $mailing->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given mailing.
     *
     * @param UserPolicy $user
     * @param Mailing $mailing
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Mailing $mailing)
    {
        return $mailing->user_id == user_id() && $mailing->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given mailing.
     *
     * @param UserPolicy $user
     * @param Mailing $mailing
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Mailing $mailing)
    {
        if ($user->canDo('mailing.mailing.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given mailing.
     *
     * @param UserPolicy $user
     * @param Mailing $mailing
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Mailing $mailing)
    {
        if ($user->canDo('mailing.mailing.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
